@@ -125,7 +125,10 @@ class Query(Table, Monad):
         return self.allExprs().getTables()
     
     def isagg(self):
-        return (self.columns.values() + self.joincond).filter(lambda x: x.isagg()).any()
+        return (self.columns.values() + self.joincond).any(lambda x: x.isagg())
+    
+    def iswindow(self):
+        return self.columns.values().any(lambda x: x.iswindow())
     
     def isOuter(self):
         return self.subQueries().exists()
