@@ -94,6 +94,9 @@ def canMoveIn(expr, inner, outer):
         # return expr in inner.joincond.children
         return expr.getTables() <= inner.baseTables()
     
+    if inner.iswindow():
+        return expr in inner.joincond.children
+    
     if expr in inner.joincond.children:
         return True
     
@@ -442,14 +445,18 @@ def isSum(q0):
     return q0.allDescendants().filter(lambda y: type(y) is AggExpr and y.func.__name__ == 'sum_').exists()
 
 def canMergeTable(tab0, tab1, subquery=False):
-    hi = (tab0.groupbys <= tab1.groupbys and tab0 in tab1.getTables() and not isSum(tab0) and not isSum(tab1)) or \
+    if tab0.iswindow() or tab1.iswindow():
+        return False
+        # return tab1.joincond == tab0.joincond
+    
+    go = (tab0.groupbys <= tab1.groupbys and tab0 in tab1.getTables() and not isSum(tab0) and not isSum(tab1)) or \
               (tab1.groupbys <= tab0.groupbys and tab1 in tab0.getTables() and not isSum(tab0) and not isSum(tab1)) or \
               ((isSum(tab0) or isSum(tab1)) and tab0.joincond == tab1.joincond and tab0.groupbys == tab1.groupbys) or \
               (tab0.groupbys == tab1.groupbys and not isSum(tab0) and not isSum(tab1))
               # or ((isSum(tab0) or isSum(tab1)) and (not tab0.isagg() or not tab1.isagg()) and tab0.groupbys == tab1.groupbys)
-    # hi &= (subquery or tab0.columns.values().filter(lambda x: not x.isagg() and not x.isPrimary()).notExists())
+    # go &= (subquery or tab0.columns.values().filter(lambda x: not x.isagg() and not x.isPrimary()).notExists())
     
-    return hi and not tab1.joincond.children.filter(lambda x: isInvalid(x, isjc=True)) \
+    return go and not tab1.joincond.children.filter(lambda x: isInvalid(x, isjc=True)) \
               and not tab0.joincond.children.filter(lambda x: isInvalid(x, isjc=True)) \
               and tab1.limitvar == tab0.limitvar and tab1.ordervar == tab0.ordervar
               # and not (not subquery and not tab0.isagg())
@@ -479,6 +486,7 @@ def mergeGrouped(self, debug=False, subquery=False):
     
     alltablegroups = (L(self) + self.subQueries()).partition(lambda x, y: canMergeTable(x, y, subquery=subquery)).filter(lambda x: len(x) > 1)
     
+    
     for tablegroup in alltablegroups:
         
         # if self in tablegroup, then use the columns = 'left' option in addquery. 
